#include "osl/move_classifier/canAttackInNMoves.h"
#include "canAttackInThreeMovesTable.h"

bool
osl::move_classifier::canAttackInThreeMoves (Player player,
					     Ptype ptype,
					     Square myPos,
					     Square opKingPos)
{
  return canAttackInThreeMovesTable
    [ptype]
    [myPos.squareForBlack(player).index()]
    [opKingPos.squareForBlack(player).index()];
}
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
